==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/ProgressiveLoadStatusEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ProgressiveLoadStatusEventArgsDescription } from "./ProgressiveLoadStatusEventArgsDescription";
/**
 * @hidden
 */
var ProgressiveLoadStatusEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ProgressiveLoadStatusEventArgsDescriptionMetadata, _super);
    function ProgressiveLoadStatusEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ProgressiveLoadStatusEventArgsDescriptionMetadata.b = function (a) {
        if (ProgressiveLoadStatusEventArgsDescriptionMetadata.a == null) {
            ProgressiveLoadStatusEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ProgressiveLoadStatusEventArgsDescriptionMetadata.c(ProgressiveLoadStatusEventArgsDescriptionMetadata.a);
        }
        if (a.g(ProgressiveLoadStatusEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(ProgressiveLoadStatusEventArgsDescriptionMetadata.a);
    };
    ProgressiveLoadStatusEventArgsDescriptionMetadata.c = function (a) {
        a.item("CurrentStatus", "Number:int");
    };
    ProgressiveLoadStatusEventArgsDescriptionMetadata.d = function (a) {
        ProgressiveLoadStatusEventArgsDescriptionMetadata.b(a);
        a.u("ProgressiveLoadStatusEventArgs", function () { return new ProgressiveLoadStatusEventArgsDescription(); });
        a.t("ProgressiveLoadStatusEventArgs", ProgressiveLoadStatusEventArgsDescriptionMetadata.a);
    };
    ProgressiveLoadStatusEventArgsDescriptionMetadata.$t = markType(ProgressiveLoadStatusEventArgsDescriptionMetadata, 'ProgressiveLoadStatusEventArgsDescriptionMetadata');
    ProgressiveLoadStatusEventArgsDescriptionMetadata.a = null;
    return ProgressiveLoadStatusEventArgsDescriptionMetadata;
}(Base));
export { ProgressiveLoadStatusEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ProgressiveLoadStatusEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ProgressiveLoadStatusEventArgsDescription } from "./ProgressiveLoadStatusEventArgsDescription";
/**
 * @hidden
 */
var ProgressiveLoadStatusEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ProgressiveLoadStatusEventArgsDescriptionMetadata, _super);
    function ProgressiveLoadStatusEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ProgressiveLoadStatusEventArgsDescriptionMetadata.b = function (a) {
        if (ProgressiveLoadStatusEventArgsDescriptionMetadata.a == null) {
            ProgressiveLoadStatusEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ProgressiveLoadStatusEventArgsDescriptionMetadata.c(ProgressiveLoadStatusEventArgsDescriptionMetadata.a);
        }
        if (a.j(ProgressiveLoadStatusEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(ProgressiveLoadStatusEventArgsDescriptionMetadata.a);
    };
    ProgressiveLoadStatusEventArgsDescriptionMetadata.c = function (a) {
        a.item("CurrentStatus", "Number:int");
    };
    ProgressiveLoadStatusEventArgsDescriptionMetadata.d = function (a) {
        ProgressiveLoadStatusEventArgsDescriptionMetadata.b(a);
        a.aa("ProgressiveLoadStatusEventArgs", function () { return new ProgressiveLoadStatusEventArgsDescription(); });
        a.z("ProgressiveLoadStatusEventArgs", ProgressiveLoadStatusEventArgsDescriptionMetadata.a);
    };
    ProgressiveLoadStatusEventArgsDescriptionMetadata.$t = markType(ProgressiveLoadStatusEventArgsDescriptionMetadata, 'ProgressiveLoadStatusEventArgsDescriptionMetadata');
    ProgressiveLoadStatusEventArgsDescriptionMetadata.a = null;
    return ProgressiveLoadStatusEventArgsDescriptionMetadata;
}(Base));
export { ProgressiveLoadStatusEventArgsDescriptionMetadata };
